# Dark Emulator
A repository for emulators of our simulation suite.
## Install
You may need to install `pyfftlog`, `george` (a software package for the Gaussian process) and colossus
```
conda install -c conda-forge george
conda install -c conda-forge pyfftlog
pip install colossus
```

You can then check if Dark Emulator works by running a tutorial notebook at
```
docs/tutorial.ipynb
docs/tutorial-hod.ipynb
```

